ai Package — pymills 3.4.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pymills 3.4.0 documentation »
- API Documentation »

# ai Package

## `deduce` Module

class `pymills.ai.deduce.` `sentence`(string)
  `adjectives` = ['A', 'AN', 'THE', 'ALL', 'EVERY', 'NONE', 'MY', 'YOUR']
  `negatives` = ['NO', 'NONE', 'NOT', 'CANNOT', 'CANT', 'WONT', 'DOESNT', 'DONT', 'ISNT', 'ARENT', 'AINT']
  `verbs` = ['IS', 'ARE', 'AM', 'BE', 'WAS', 'WERE', 'BE']
  `helping_verbs` = ['DO', 'DOES', 'CAN', 'WILL', 'HAS', 'HAVE']
  `contractions` = {'DONT': ['DO', 'NOT'], 'ILL': ['I', 'WILL'], 'YOURE': ['YOU', 'ARE'], 'ISNT': ['IS', 'NOT'], 'DOESNT': ['DOES', 'NOT'], 'IM': ['I', 'AM'], 'ARENT': ['ARE', 'NOT'], 'WERENT': ['WERE', 'NOT'], 'YOULL': ['YOU', 'WILL'], 'WONT': ['WILL', 'NOT'], 'WASNT': ['WAS', 'NOT'], 'CANT': ['CAN', 'NOT'], 'CANNOT': ['CAN', 'NOT']}
  `next_word`()
  `prev_word`()
  `rewind_words`()
  `next_phrase`()
  `is_question`()

class `pymills.ai.deduce.` `fact`(statement)
  `subj_adj` = ''
  `subj` = ''
  `helping_verb` = ''
  `verb` = ''
  `orig_verb` = ''
  `obj_adj` = ''
  `obj` = ''
  `question` = 0
  `negative` = 0
  `seen` = 0
  `to_be` = ['IS', 'ARE', 'AM', 'BE', 'WAS', 'WERE']
  `translate`(statement)
  `swap_person`()

class `pymills.ai.deduce.` `brain`
  `to_be` = ['IS', 'ARE', 'BE', 'WAS', 'WERE']
  `learn`(newfact)
  `describe_subj`(subject)
  `query`(question)
  `query_i`(q)

`pymills.ai.deduce.` `ui`()

### Navigation

- index
- modules |
- next |
- previous |
- pymills 3.4.0 documentation »
- API Documentation »